#[repr(transparent)]pub struct Dcdc1(pub u32);Expand description
DCDC (second) control register [Reset by: PoR, Pin Reset, Brown Out Detectors Reset, Deep Power Down Reset, Software Reset]
Tuple Fields
0: u32Implementations
Sourceimpl Dcdc1
impl Dcdc1
Sourcepub const fn rtrimoffet(&self) -> u8
pub const fn rtrimoffet(&self) -> u8
Adjust the offset voltage of BJT based comparator.
Sourcepub const fn set_rtrimoffet(&mut self, val: u8)
pub const fn set_rtrimoffet(&mut self, val: u8)
Adjust the offset voltage of BJT based comparator.
Sourcepub const fn rsensetrim(&self) -> u8
pub const fn rsensetrim(&self) -> u8
Adjust Max inductor peak current limiting.
Sourcepub const fn set_rsensetrim(&mut self, val: u8)
pub const fn set_rsensetrim(&mut self, val: u8)
Adjust Max inductor peak current limiting.
Sourcepub const fn dtestenable(&self) -> bool
pub const fn dtestenable(&self) -> bool
Enable Digital test signals.
Sourcepub const fn set_dtestenable(&mut self, val: bool)
pub const fn set_dtestenable(&mut self, val: bool)
Enable Digital test signals.
Sourcepub const fn set_setcurve(&mut self, val: u8)
pub const fn set_setcurve(&mut self, val: u8)
Bandgap calibration parameter.
Sourcepub const fn set_dtestsel(&mut self, val: u8)
pub const fn set_dtestsel(&mut self, val: u8)
Select the output signal for test.
Sourcepub const fn iscaleenable(&self) -> bool
pub const fn iscaleenable(&self) -> bool
Modify COT behavior.
Sourcepub const fn set_iscaleenable(&mut self, val: bool)
pub const fn set_iscaleenable(&mut self, val: bool)
Modify COT behavior.
Sourcepub const fn forcebypass(&self) -> bool
pub const fn forcebypass(&self) -> bool
Force bypass mode.
Sourcepub const fn set_forcebypass(&mut self, val: bool)
pub const fn set_forcebypass(&mut self, val: bool)
Force bypass mode.
Sourcepub const fn trimautocot(&self) -> u8
pub const fn trimautocot(&self) -> u8
Change the scaling ratio of the feedforward compensation.
Sourcepub const fn set_trimautocot(&mut self, val: u8)
pub const fn set_trimautocot(&mut self, val: u8)
Change the scaling ratio of the feedforward compensation.
Sourcepub const fn forcefullcycle(&self) -> bool
pub const fn forcefullcycle(&self) -> bool
Force full PFM PMOS and NMOS cycle.
Sourcepub const fn set_forcefullcycle(&mut self, val: bool)
pub const fn set_forcefullcycle(&mut self, val: bool)
Force full PFM PMOS and NMOS cycle.
Sourcepub const fn lcenable(&self) -> bool
pub const fn lcenable(&self) -> bool
Change the range of the peak detector of current inside the inductor.
Sourcepub const fn set_lcenable(&mut self, val: bool)
pub const fn set_lcenable(&mut self, val: bool)
Change the range of the peak detector of current inside the inductor.
Sourcepub const fn toffenable(&self) -> bool
pub const fn toffenable(&self) -> bool
Enable Constant Off-Time feature.
Sourcepub const fn set_toffenable(&mut self, val: bool)
pub const fn set_toffenable(&mut self, val: bool)
Enable Constant Off-Time feature.