nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Ostimer

Struct Ostimer 

#[repr(transparent)]
pub struct Ostimer(pub u32);
OS Timer control register [Reset by: PoR, Brown Out Detectors Reset]

Tuple Fields

0: u32

Implementations

Source

impl Ostimer

pub const fn softreset(&self) -> bool

Active high reset.

pub const fn set_softreset(&mut self, val: bool)

Active high reset.

pub const fn clockenable(&self) -> bool

Enable OSTIMER 32 KHz clock.

pub const fn set_clockenable(&mut self, val: bool)

Enable OSTIMER 32 KHz clock.

pub const fn dpdwakeupenable(&self) -> bool

Wake up enable in Deep Power Down mode (To be used in Enable Deep Power Down mode).

pub const fn set_dpdwakeupenable(&mut self, val: bool)

Wake up enable in Deep Power Down mode (To be used in Enable Deep Power Down mode).

pub const fn osc32kpd(&self) -> bool

Oscilator 32KHz (either FRO32KHz or XTAL32KHz according to RTCOSC32K.

pub const fn set_osc32kpd(&mut self, val: bool)

Oscilator 32KHz (either FRO32KHz or XTAL32KHz according to RTCOSC32K.