nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Pdruncfg0

Struct Pdruncfg0 

#[repr(transparent)]
pub struct Pdruncfg0(pub u32);
Controls the power to various analog blocks [Reset by: PoR, Pin Reset, Brown Out Detectors Reset, Deep Power Down Reset, Software Reset]

Tuple Fields

0: u32

Implementations

Source

impl Pdruncfg0

pub const fn pden_bodvbat(&self) -> PdenBodvbat

Controls power to VBAT Brown Out Detector (BOD).

pub const fn set_pden_bodvbat(&mut self, val: PdenBodvbat)

Controls power to VBAT Brown Out Detector (BOD).

pub const fn pden_fro32k(&self) -> PdenFro32k

Controls power to the Free Running Oscillator (FRO) 32 KHz.

pub const fn set_pden_fro32k(&mut self, val: PdenFro32k)

Controls power to the Free Running Oscillator (FRO) 32 KHz.

pub const fn pden_xtal32k(&self) -> PdenXtal32k

Controls power to crystal 32 KHz.

pub const fn set_pden_xtal32k(&mut self, val: PdenXtal32k)

Controls power to crystal 32 KHz.

pub const fn pden_xtal32m(&self) -> PdenXtal32m

Controls power to high speed crystal.

pub const fn set_pden_xtal32m(&mut self, val: PdenXtal32m)

Controls power to high speed crystal.

pub const fn pden_pll0(&self) -> PdenPll0

Controls power to System PLL (also refered as PLL0).

pub const fn set_pden_pll0(&mut self, val: PdenPll0)

Controls power to System PLL (also refered as PLL0).

pub const fn pden_pll1(&self) -> PdenPll1

Controls power to USB PLL (also refered as PLL1).

pub const fn set_pden_pll1(&mut self, val: PdenPll1)

Controls power to USB PLL (also refered as PLL1).

pub const fn pden_usbfsphy(&self) -> PdenUsbfsphy

Controls power to USB Full Speed phy.

pub const fn set_pden_usbfsphy(&mut self, val: PdenUsbfsphy)

Controls power to USB Full Speed phy.

pub const fn pden_usbhsphy(&self) -> PdenUsbhsphy

Controls power to USB High Speed Phy.

pub const fn set_pden_usbhsphy(&mut self, val: PdenUsbhsphy)

Controls power to USB High Speed Phy.

pub const fn pden_comp(&self) -> PdenComp

Controls power to Analog Comparator.

pub const fn set_pden_comp(&mut self, val: PdenComp)

Controls power to Analog Comparator.

pub const fn pden_ldousbhs(&self) -> PdenLdousbhs

Controls power to USB high speed LDO.

pub const fn set_pden_ldousbhs(&mut self, val: PdenLdousbhs)

Controls power to USB high speed LDO.

pub const fn pden_auxbias(&self) -> PdenAuxbias

Controls power to auxiliary biasing (AUXBIAS)

pub const fn set_pden_auxbias(&mut self, val: PdenAuxbias)

Controls power to auxiliary biasing (AUXBIAS)

pub const fn pden_ldoxo32m(&self) -> PdenLdoxo32m

Controls power to high speed crystal LDO.

pub const fn set_pden_ldoxo32m(&mut self, val: PdenLdoxo32m)

Controls power to high speed crystal LDO.

pub const fn pden_rng(&self) -> PdenRng

Controls power to all True Random Number Genetaor (TRNG) clock sources.

pub const fn set_pden_rng(&mut self, val: PdenRng)

Controls power to all True Random Number Genetaor (TRNG) clock sources.

pub const fn pden_pll0_sscg(&self) -> PdenPll0Sscg

Controls power to System PLL (PLL0) Spread Spectrum module.

pub const fn set_pden_pll0_sscg(&mut self, val: PdenPll0Sscg)

Controls power to System PLL (PLL0) Spread Spectrum module.