nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Pdruncfgset0

Struct Pdruncfgset0 

#[repr(transparent)]
pub struct Pdruncfgset0(pub u32);
Controls the power to various analog blocks [Reset by: PoR, Pin Reset, Brown Out Detectors Reset, Deep Power Down Reset, Software Reset]

Tuple Fields

0: u32

Implementations

Source

impl Pdruncfgset0

pub const fn pdruncfgset0(&self) -> u32

Writing ones to this register sets the corresponding bit or bits in the PDRUNCFG0 register, if they are implemented.

pub const fn set_pdruncfgset0(&mut self, val: u32)

Writing ones to this register sets the corresponding bit or bits in the PDRUNCFG0 register, if they are implemented.