nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Rtcosc32k

Struct Rtcosc32k 

#[repr(transparent)]
pub struct Rtcosc32k(pub u32);
RTC 1 KHZ and 1 Hz clocks source control register [Reset by: PoR, Brown Out Detectors Reset]

Tuple Fields

0: u32

Implementations

Source

impl Rtcosc32k

pub const fn sel(&self) -> Sel

Select the 32K oscillator to be used in Deep Power Down Mode for the RTC (either XTAL32KHz or FRO32KHz) .

pub const fn set_sel(&mut self, val: Sel)

Select the 32K oscillator to be used in Deep Power Down Mode for the RTC (either XTAL32KHz or FRO32KHz) .

pub const fn clk1khzdiv(&self) -> u8

Actual division ratio is : 28 + CLK1KHZDIV.

pub const fn set_clk1khzdiv(&mut self, val: u8)

Actual division ratio is : 28 + CLK1KHZDIV.

pub const fn clk1khzdivupdatereq(&self) -> bool

RTC 1KHz clock Divider status flag.

pub const fn set_clk1khzdivupdatereq(&mut self, val: bool)

RTC 1KHz clock Divider status flag.

pub const fn clk1hzdiv(&self) -> u16

Actual division ratio is : 31744 + CLK1HZDIV.

pub const fn set_clk1hzdiv(&mut self, val: u16)

Actual division ratio is : 31744 + CLK1HZDIV.

pub const fn clk1hzdivhalt(&self) -> bool

Halts the divider counter.

pub const fn set_clk1hzdivhalt(&mut self, val: bool)

Halts the divider counter.

pub const fn clk1hzdivupdatereq(&self) -> bool

RTC 1Hz Divider status flag.

pub const fn set_clk1hzdivupdatereq(&mut self, val: bool)

RTC 1Hz Divider status flag.