#[repr(transparent)]pub struct Miscctrl(pub u32);Expand description
Dummy Control bus to PMU [Reset by: PoR, Pin Reset, Brown Out Detectors Reset, Deep Power Down Reset, Software Reset]
Tuple Fields
0: u32Implementations
Sourceimpl Miscctrl
impl Miscctrl
Sourcepub const fn ldodeepsleepref(&self) -> Ldodeepsleepref
pub const fn ldodeepsleepref(&self) -> Ldodeepsleepref
Select LDO Deep Sleep reference source.
Sourcepub const fn set_ldodeepsleepref(&mut self, val: Ldodeepsleepref)
pub const fn set_ldodeepsleepref(&mut self, val: Ldodeepsleepref)
Select LDO Deep Sleep reference source.
Sourcepub const fn ldomemhighzmode(&self) -> bool
pub const fn ldomemhighzmode(&self) -> bool
Control the activation of LDO MEM High Z mode.
Sourcepub const fn set_ldomemhighzmode(&mut self, val: bool)
pub const fn set_ldomemhighzmode(&mut self, val: bool)
Control the activation of LDO MEM High Z mode.
Sourcepub const fn lowpwr_flash_buf(&self) -> bool
pub const fn lowpwr_flash_buf(&self) -> bool
no description available
Sourcepub const fn set_lowpwr_flash_buf(&mut self, val: bool)
pub const fn set_lowpwr_flash_buf(&mut self, val: bool)
no description available
Sourcepub const fn miscctrl_3_8(&self) -> u8
pub const fn miscctrl_3_8(&self) -> u8
Reserved.
Sourcepub const fn set_miscctrl_3_8(&mut self, val: u8)
pub const fn set_miscctrl_3_8(&mut self, val: u8)
Reserved.
Sourcepub const fn modewakeup0(&self) -> bool
pub const fn modewakeup0(&self) -> bool
Configure wake up I/O 0 in Deep Power Down mode
Sourcepub const fn set_modewakeup0(&mut self, val: bool)
pub const fn set_modewakeup0(&mut self, val: bool)
Configure wake up I/O 0 in Deep Power Down mode
Sourcepub const fn modewakeup1(&self) -> bool
pub const fn modewakeup1(&self) -> bool
Configure wake up I/O 1 in Deep Power Down mode
Sourcepub const fn set_modewakeup1(&mut self, val: bool)
pub const fn set_modewakeup1(&mut self, val: bool)
Configure wake up I/O 1 in Deep Power Down mode
Sourcepub const fn modewakeup2(&self) -> bool
pub const fn modewakeup2(&self) -> bool
Configure wake up I/O 2 in Deep Power Down mode
Sourcepub const fn set_modewakeup2(&mut self, val: bool)
pub const fn set_modewakeup2(&mut self, val: bool)
Configure wake up I/O 2 in Deep Power Down mode
Sourcepub const fn modewakeup3(&self) -> bool
pub const fn modewakeup3(&self) -> bool
Configure wake up I/O 3 in Deep Power Down mode
Sourcepub const fn set_modewakeup3(&mut self, val: bool)
pub const fn set_modewakeup3(&mut self, val: bool)
Configure wake up I/O 3 in Deep Power Down mode
Sourcepub const fn disable_bleed(&self) -> DisableBleed
pub const fn disable_bleed(&self) -> DisableBleed
Controls LDO MEM bleed current. This field is expected to be controlled by the Low Power Software only in DEEP SLEEP low power mode.
Sourcepub const fn set_disable_bleed(&mut self, val: DisableBleed)
pub const fn set_disable_bleed(&mut self, val: DisableBleed)
Controls LDO MEM bleed current. This field is expected to be controlled by the Low Power Software only in DEEP SLEEP low power mode.
Sourcepub const fn miscctrl_13_14(&self) -> u8
pub const fn miscctrl_13_14(&self) -> u8
Reserved.
Sourcepub const fn set_miscctrl_13_14(&mut self, val: u8)
pub const fn set_miscctrl_13_14(&mut self, val: u8)
Reserved.
Sourcepub const fn wakupio_rst(&self) -> WakupioRst
pub const fn wakupio_rst(&self) -> WakupioRst
WAKEUP IO event detector reset control.
Sourcepub const fn set_wakupio_rst(&mut self, val: WakupioRst)
pub const fn set_wakupio_rst(&mut self, val: WakupioRst)
WAKEUP IO event detector reset control.